@@ -17,17 +17,17 @@
 
 # pylint: skip-file
 
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
-import re
-import sys
-import math
-import time
 import array
 import codecs
-import inspect
-import platform
 import importlib
+import inspect
+import math
+import platform
+import re
+import sys
+import time
 from base64 import b64encode
 from collections import namedtuple
 
@@ -48,16 +48,14 @@ if False:
 
 PY2 = sys.version_info[0] == 2
 PY3 = sys.version_info[0] == 3
-PYPY = platform.python_implementation() == 'PyPy'
+PYPY = platform.python_implementation() == "PyPy"
 CAN_UNPACK_BYTE_ARRAY = sys.version_info[:3] >= (2, 7, 4)
 CAN_PACK_HALF_FLOAT = sys.version_info[:2] >= (3, 6)
 
-WINDOWS = platform.system() == 'Windows'
+WINDOWS = platform.system() == "Windows"
 
 if sys.version_info[:2] <= (2, 6):
-    raise ImportError(
-        'Hypothesis is not supported on Python versions before 2.7'
-    )
+    raise ImportError("Hypothesis is not supported on Python versions before 2.7")
 
 
 def bit_length(n):
@@ -70,6 +68,7 @@ def quiet_raise(exc):
 
 
 if PY3:
+
     def str_to_bytes(s):
         return s.encode(a_good_encoding())
 
@@ -79,7 +78,7 @@ if PY3:
     text_type = str
     binary_type = bytes
     hrange = range
-    ARG_NAME_ATTRIBUTE = 'arg'
+    ARG_NAME_ATTRIBUTE = "arg"
     integer_types = (int,)
     _long_integer_type = int
     hunichr = chr
@@ -91,21 +90,23 @@ if PY3:
         return s.isidentifier()
 
     def escape_unicode_characters(s):
-        return codecs.encode(s, 'unicode_escape').decode('ascii')
+        return codecs.encode(s, "unicode_escape").decode("ascii")
 
     def print_unicode(x):
         print(x)
 
-    exec("""
+    exec(
+        """
 def quiet_raise(exc):
     raise exc from None
-""")
+"""
+    )
 
     def int_from_bytes(data):
-        return int.from_bytes(data, 'big')
+        return int.from_bytes(data, "big")
 
     def int_to_bytes(i, size):
-        return i.to_bytes(size, 'big')
+        return i.to_bytes(size, "big")
 
     def to_bytes_sequence(ls):
         return bytes(ls)
@@ -120,6 +121,8 @@ def quiet_raise(exc):
 
     def benchmark_time():
         return time.monotonic()
+
+
 else:
     import struct
 
@@ -127,9 +130,12 @@ else:
         return hbytes(struct.pack(*args))
 
     if CAN_UNPACK_BYTE_ARRAY:
+
         def struct_unpack(fmt, string):
             return struct.unpack(fmt, string)
+
     else:
+
         def struct_unpack(fmt, string):
             return struct.unpack(fmt, str(string))
 
@@ -145,7 +151,7 @@ else:
         i = 0
         while i + 4 <= len(data):
             result <<= 32
-            result |= struct.unpack('>I', unpackable_data[i:i + 4])[0]
+            result |= struct.unpack(">I", unpackable_data[i : i + 4])[0]
             i += 4
         while i < len(data):
             result <<= 8
@@ -163,8 +169,7 @@ else:
             i >>= 8
             j -= 1
         if i:
-            raise OverflowError('i=%r cannot be represented in %r bytes'
-                                % (arg, size))
+            raise OverflowError("i=%r cannot be represented in %r bytes" % (arg, size))
         return hbytes(result)
 
     int_to_byte = chr
@@ -176,11 +181,9 @@ else:
         return s
 
     def int_to_text(i):
-        return str(i).decode('ascii')
+        return str(i).decode("ascii")
 
-    VALID_PYTHON_IDENTIFIER = re.compile(
-        r"^[a-zA-Z_][a-zA-Z0-9_]*$"
-    )
+    VALID_PYTHON_IDENTIFIER = re.compile(r"^[a-zA-Z_][a-zA-Z0-9_]*$")
 
     def isidentifier(s):
         return VALID_PYTHON_IDENTIFIER.match(s)
@@ -204,7 +207,7 @@ else:
                 return xrange(start_or_finish, finish, step)
         except OverflowError:
             if step == 0:
-                raise ValueError(u'step argument may not be zero')
+                raise ValueError(u"step argument may not be zero")
             if step is None:
                 step = 1
             if finish is not None:
@@ -214,26 +217,30 @@ else:
                 finish = start_or_finish
             assert step != 0
             if step > 0:
+
                 def shimrange():
                     i = start
                     while i < finish:
                         yield i
                         i += step
+
             else:
+
                 def shimrange():
                     i = start
                     while i > finish:
                         yield i
                         i += step
+
             return shimrange()
 
-    ARG_NAME_ATTRIBUTE = 'id'
+    ARG_NAME_ATTRIBUTE = "id"
     integer_types = (int, long)
     _long_integer_type = long
     hunichr = unichr
 
     def escape_unicode_characters(s):
-        return codecs.encode(s, 'string_escape')
+        return codecs.encode(s, "string_escape")
 
     def print_unicode(x):
         if isinstance(x, unicode):
@@ -251,18 +258,22 @@ else:
 # into a string file path using the appropriate encoding. See
 # https://bitbucket.org/ned/coveragepy/issues/602/ for more information.
 if PY2:
+
     def encoded_filepath(filepath):
         if isinstance(filepath, text_type):
             return filepath.encode(sys.getfilesystemencoding())
         else:
             return filepath
+
+
 else:
+
     def encoded_filepath(filepath):
         return filepath
 
 
 def a_good_encoding():
-    return 'utf-8'
+    return "utf-8"
 
 
 def to_unicode(x):
@@ -278,7 +289,7 @@ def qualname(f):
     except AttributeError:
         pass
     try:
-        return f.im_class.__name__ + '.' + f.__name__
+        return f.im_class.__name__ + "." + f.__name__
     except AttributeError:
         return f.__name__
 
@@ -289,9 +300,8 @@ except ImportError:
     typing_root_type = ()  # type: Tuple[type, ...]
     ForwardRef = None
 else:
-    if hasattr(typing, '_Final'):  # new in Python 3.7
-        typing_root_type = (
-            typing._Final, typing._GenericAlias)  # type: ignore
+    if hasattr(typing, "_Final"):  # new in Python 3.7
+        typing_root_type = (typing._Final, typing._GenericAlias)  # type: ignore
         ForwardRef = typing.ForwardRef  # type: ignore
     else:
         typing_root_type = (typing.TypingMeta, typing.TypeVar)  # type: ignore
@@ -299,27 +309,42 @@ else:
 
 
 if PY2:
-    FullArgSpec = namedtuple('FullArgSpec', 'args, varargs, varkw, defaults, '
-                             'kwonlyargs, kwonlydefaults, annotations')
+    FullArgSpec = namedtuple(
+        "FullArgSpec",
+        "args, varargs, varkw, defaults, " "kwonlyargs, kwonlydefaults, annotations",
+    )
 
     def getfullargspec(func):
         args, varargs, varkw, defaults = inspect.getargspec(func)
-        return FullArgSpec(args, varargs, varkw, defaults, [], None,
-                           getattr(func, '__annotations__', {}))
+        return FullArgSpec(
+            args,
+            varargs,
+            varkw,
+            defaults,
+            [],
+            None,
+            getattr(func, "__annotations__", {}),
+        )
+
+
 else:
     from inspect import getfullargspec, FullArgSpec
 
 
 if sys.version_info[:2] < (3, 6):
+
     def get_type_hints(thing):
         try:
             spec = getfullargspec(thing)
             return {
-                k: v for k, v in spec.annotations.items()
+                k: v
+                for k, v in spec.annotations.items()
                 if k in (spec.args + spec.kwonlyargs) and isinstance(v, type)
             }
         except TypeError:
             return {}
+
+
 else:
     import typing
 
@@ -330,44 +355,43 @@ else:
             return {}
 
 
-importlib_invalidate_caches = getattr(
-    importlib, 'invalidate_caches', lambda: ())
+importlib_invalidate_caches = getattr(importlib, "invalidate_caches", lambda: ())
 
 
 if PY2:
     CODE_FIELD_ORDER = [
-        'co_argcount',
-        'co_nlocals',
-        'co_stacksize',
-        'co_flags',
-        'co_code',
-        'co_consts',
-        'co_names',
-        'co_varnames',
-        'co_filename',
-        'co_name',
-        'co_firstlineno',
-        'co_lnotab',
-        'co_freevars',
-        'co_cellvars',
+        "co_argcount",
+        "co_nlocals",
+        "co_stacksize",
+        "co_flags",
+        "co_code",
+        "co_consts",
+        "co_names",
+        "co_varnames",
+        "co_filename",
+        "co_name",
+        "co_firstlineno",
+        "co_lnotab",
+        "co_freevars",
+        "co_cellvars",
     ]
 else:
     CODE_FIELD_ORDER = [
-        'co_argcount',
-        'co_kwonlyargcount',
-        'co_nlocals',
-        'co_stacksize',
-        'co_flags',
-        'co_code',
-        'co_consts',
-        'co_names',
-        'co_varnames',
-        'co_filename',
-        'co_name',
-        'co_firstlineno',
-        'co_lnotab',
-        'co_freevars',
-        'co_cellvars',
+        "co_argcount",
+        "co_kwonlyargcount",
+        "co_nlocals",
+        "co_stacksize",
+        "co_flags",
+        "co_code",
+        "co_consts",
+        "co_names",
+        "co_varnames",
+        "co_filename",
+        "co_name",
+        "co_firstlineno",
+        "co_lnotab",
+        "co_freevars",
+        "co_cellvars",
     ]
 
 
@@ -381,16 +405,14 @@ def update_code_location(code, newfile, newlineno):
     code you're probably here because it's broken something and now
     you're angry at me. Sorry.
     """
-    unpacked = [
-        getattr(code, name) for name in CODE_FIELD_ORDER
-    ]
-    unpacked[CODE_FIELD_ORDER.index('co_filename')] = newfile
-    unpacked[CODE_FIELD_ORDER.index('co_firstlineno')] = newlineno
+    unpacked = [getattr(code, name) for name in CODE_FIELD_ORDER]
+    unpacked[CODE_FIELD_ORDER.index("co_filename")] = newfile
+    unpacked[CODE_FIELD_ORDER.index("co_firstlineno")] = newlineno
     return type(code)(*unpacked)
 
 
 class compatbytes(bytearray):
-    __name__ = 'bytes'
+    __name__ = "bytes"
 
     def __init__(self, *args, **kwargs):
         bytearray.__init__(self, *args, **kwargs)
@@ -400,7 +422,7 @@ class compatbytes(bytearray):
         return bytearray.__str__(self)
 
     def __repr__(self):
-        return 'compatbytes(b%r)' % (str(self),)
+        return "compatbytes(b%r)" % (str(self),)
 
     def __hash__(self):
         if self.__hash is None:
@@ -418,7 +440,7 @@ class compatbytes(bytearray):
         for i, v in enumerate(self):
             if v == value:
                 return i
-        raise ValueError('Value %r not in sequence %r' % (value, self))
+        raise ValueError("Value %r not in sequence %r" % (value, self))
 
     def __add__(self, value):
         assert isinstance(value, compatbytes)
@@ -467,32 +489,36 @@ else:
     string_types = (str,)
 
 
-EMPTY_BYTES = hbytes(b'')
+EMPTY_BYTES = hbytes(b"")
 
 if PY2:
+
     def to_str(s):
         if isinstance(s, unicode):
             return s.encode(a_good_encoding())
         assert isinstance(s, str)
         return s
+
+
 else:
+
     def to_str(s):
         return s
 
 
 def cast_unicode(s, encoding=None):
     if isinstance(s, bytes):
-        return s.decode(encoding or a_good_encoding(), 'replace')
+        return s.decode(encoding or a_good_encoding(), "replace")
     return s
 
 
 def get_stream_enc(stream, default=None):
-    return getattr(stream, 'encoding', None) or default
+    return getattr(stream, "encoding", None) or default
 
 
 def implements_iterator(it):
     """Turn things with a __next__ attribute into iterators on Python 2."""
-    if PY2 and not hasattr(it, 'next') and hasattr(it, '__next__'):
+    if PY2 and not hasattr(it, "next") and hasattr(it, "__next__"):
         it.next = it.__next__
     return it
 
@@ -545,9 +571,13 @@ except ImportError:
 
 
 if PY2:
+
     def b64decode(s):
         from base64 import b64decode as base
+
         return hbytes(base(s))
+
+
 else:
     from base64 import b64decode
 
@@ -559,8 +589,11 @@ try:
     def bad_django_TestCase(runner):
         if runner is None:
             return False
-        return isinstance(runner, TransactionTestCase) and \
-            not isinstance(runner, HypothesisTestCase)
+        return isinstance(runner, TransactionTestCase) and not isinstance(
+            runner, HypothesisTestCase
+        )
+
+
 except Exception:
     # Can't use ImportError, because of e.g. Django config errors
     def bad_django_TestCase(runner):
